use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007004
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
Alders
Alders'
Contributors
DROLSKY
DROLSKY's
Dave
Dist
Eilam
Eilam's
Fowler
Greg
Hunter
Inc
License
MAXMIND
Mark
Mateu
MaxMind
MaxMind's
Olaf
Oschwald
Oschwald's
PayPal
Plugin
PluginBundle
Ran
Rolsky
Rolsky's
Zilla
drolsky
goschwald
lib
mfowler
mhunter
oalders
perlcriticrc
perltidyrc
reilam
tidyall
